***************************************************************************************************************
***Information from Relationship Lending: Evidence from Loan Defaults in China (Chang, Liao, Yu, and Ni; JMCB)
***************************************************************************************************************
version 11.2
clear all
set more off
capture log close

cd F:\Stata11\bankrating

******************************************************************************************
***data processing
******************************************************************************************

use sample0,clear  

/*variable definition

code: firm code
year: the year when the loan is originated, year is between 2003 and 2006
ind: industry classification
rating: the class of rating set by the bank
ownership: the type of ownership; =10 state-owned
                                  =20 collectively-owned
								  =30 state-controlled
								  =40 collectively-controlled
								  =50 foreign-owned and joint ventures
								  =60 privately-owned
								  =70 proprietorship
								  =... others
								  =190 missing
labor: the number of employees
notecode: loan code
province: the code of province where the loan is originated
loandate: the date when the loan is originated
paydate: the date when the loan is due
balance: the balance of the loan at the end of the year
condition: =1 if the loan is repaid at the end of the following year
		   =2 if the loan is written off at the end of the following year
		   =3 if the loan is unpaid at the end of the following year
type_maturity: =0 if maturity < 1 year 
               =1 if maturity = 1 year
               =2 if 1 year < maturity <= 5 years
			   =3 if maturity > 5 years  
maturity_month (for short-term loans): =1 if maturity <=1 month
                                       =2 if 1 month < maturity <= 2 months
									   =3 if 2 months < maturity <= 3 months
									   ...
									   =12 if 11 months < maturity <=12 months
lagdefault: =1 if the firm has defaulted on loans before
            =0 otherwise
public: =1 if the firm is publicly traded
        =0 otherwise

*/

gen csrc_a=substr(ind,1,3)   //Industry code

***generate the time interval since the date when the firm obtained a loan from the bank for the first time 
merge m:1 code using loandate_first  //introduce the date (f_date) when the firm obtained a loan from the bank for the first time
drop if _merge==2  
drop _merge
gen dif_month=(year(loandate)-year(f_date))*12+ month(loandate)-month(f_date)  //dif_month is the number of months between the date when the loan is originated and the date when the firm obtained a loan from the bank for the first time

***generate the times that the firm has borrowed from the bank during 2003-2006
preserve
bysort code:gen times=_N
bysort code:keep if _n==1
keep code times
save x,replace
restore
merge m:1 code using x
drop if _merge==2
drop _merge

***generate the natural log of GDP per capita of the province where the loan is originated (lngdp) and the code of the region where the loan is originated (field)
preserve
use gdp,clear
keep province year lngdp field   
/*
province: the province code
year: a certain year
lngdp: the natural log of GDP per capita of the province
field: the code of economic region which the province belongs to; =1 Eastern region
                                                                  =2 Southwestern region
																  =3 Northern region
																  =4 Central Southern region
																  =5 Northwestern region
																  =6 Northeastern region
*/
save x,replace
restore
merge m:1 province year using x
drop if _merge==2
drop _merge


***generate the variable credit rating: rating_b
gen rating_b=12 if rating==10
replace rating_b=11 if rating==20
replace rating_b=10 if rating==21
replace rating_b=9 if rating==22
replace rating_b=8 if rating==30
replace rating_b=7 if rating==31
replace rating_b=6 if rating==32
replace rating_b=5 if rating==40
replace rating_b=4 if rating==41
replace rating_b=3 if rating==42
replace rating_b=2 if rating==50
replace rating_b=1 if rating==60

***generate the ownership dummy for the state-owned enterprise: state
gen state=1 if ownership==10 | ownership==30  //if the firm is owned or controlled by the state
replace state=0 if state==.
replace state=. if ownership==190 | ownership==20 | ownership==40 // missing information on ownership, collectively-owned firms and collectively-controlled firms

***generate the variable default at loan level
gen default=(condition==2 | condition==3) if condition!=. & type_maturity<=1 //default occurs if a short-term loan is unpaid or written off at the end of the following year 

save samplex,replace

***generate financial variables
preserve
use financedata,clear //financial dataset
egen id=group(code) //code is firm id
xtset id year
gen lnasset=ln(asset*10000)  //generate the size proxy (lnasset), total assets in our dataset is in ten thousands
gen lev=liability/asset  //generate leverage proxy (lev)
gen roe=nincome/equity if equity>0 //generate profitablity proxy (roe), nincome is firm's net income 
gen sgrow=sales/l.sales-1 if l.sales>0 //generate growth proxy (sgrow) which is measured by sales growth
gen cashas=casset/asset  //generate Cash proxy, casset is firm's current assets  
gen asturn=sales/nfixas if nfixas>0  //generate asset turnover proxy (asturn), nfixas is firm's Plant, Property and Equipment 
replace year=year+1  //we will use lag of financial variables  
keep code year lnasset lev roe asturn sgrow cashas asset sales equity nincome nfixas
save x,replace
restore
merge m:1 code year using x
drop if _merge==2
drop _merge
gen dum=(sgrow==.)  //generate a dummy indicating that the initial sales growth is missing 
replace sgrow=0 if sgrow==.  //replace the variable sgrow with 0 if the initial sales growth is missing
replace labor=. if labor==0  //the variable labor is the number of employees; we set it as missing if it is listed as 0 in the dataset (it may be data error or missing)

***sample selection

keep if year>=2004 & year<=2006

drop if ownership==190   //drop firms with missing information on ownership 

drop if ownership==20 | ownership==40  //drop collectively-owned or collectively-controlled firms

drop if rating_b==.  //drop firms with missing information on internal rating scores
drop if asset==. | sales==. | nincome==. //drop firms with missing financial statement information
drop if equity<0  //drop firms with negative equity
drop if nfixas==0  //drop firms with zero value associated with Plant, Property and Equipment (PP&E)

drop if year==2006  //drop loans that were originated in 2006

/*focus on defaults on short-term loans*/
drop if type_maturity>1  //drop loans whose maturity exceeds one year 
drop if year(paydate)==year(loandate)  //drop short-term loans made and repaid within the same calendar year

save sample_loan,replace 


use sample_loan,clear

***generate the variable default at firm level (if a firm defaults on at least one of its short-term loans during the subsequent year)
bysort year code:egen sum_default=sum(default)
replace sum_default=1 if sum_default>0 & sum_default<.
drop default
rename sum_default default

***generate weighted average loan maturity (maturity_wt, in months)
bysort year code: egen sum_balance=sum(balance)
gen x=maturity_month*balance/sum_balance
bysort year code: egen maturity_wt=sum(x) 
drop x  

***keep the last loan in a given year for a firm
sort year code loandate
bysort year code: keep if _n==_N

save sample2,replace


************************************************************
***regression analysis
************************************************************

use sample2,clear

global out     outreg2 using 
global option1  bdec(3) tdec(2) excel replace
global option2  bdec(3) tdec(2) excel append
global add1  addstat(Pseudo R-squared, e(r2_p),chi2 test, e(p),chi2 test, e(chi2))
global add2  addstat(F test, e(p),Adj R-squared, e(r2_a),F test, e(F))
 
foreach var of varlist asturn sgrow  {
winsor `var', p(0.01) gen(`var'_w)
drop `var'
rename `var'_w `var'
}


********************************************
***Determinants of Loan Default
********************************************

global table table2

xi: probit  default lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r
$out $table, $option1 $add1 
xi: dprobit default lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r   //get marginal effects
$out $table, $option2 $add1 

xi: probit  default rating_b i.field i.year i.csrc_a,r
$out $table, $option2 $add1 
xi: dprobit default rating_b i.field i.year i.csrc_a,r  //get marginal effects
$out $table, $option2 $add1

xi: probit  default rating_b lnasset lev roe asturn  cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r
$out $table, $option2 $add1 
xi: dprobit default rating_b lnasset lev roe asturn  cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r  //get marginal effects
$out $table, $option2 $add1


******************************************************************
***regress credit rating on financial ratios
******************************************************************

/*level analysis*/

global table table3

xi:reg rating_b lnasset lev roe asturn cashas sgrow dum lagdefault public state maturity_wt lngdp i.field i.year i.csrc_a,r
$out $table, $option1 $add2 
predict residual,r  //get the proxy for bank specialty (residual)
save sample3,replace

/*change analysis*/

use samplex,clear

***sample selection for change analysis

drop if ownership==190   
drop if ownership==20 | ownership==40  

keep if year==2004 | year==2005 | year==2006

drop if type_maturity>1 
drop if year(paydate)==year(loandate)  

bysort year code: egen sum_balance=total(balance)
gen x=maturity_month*balance/sum_balance
bysort year code: egen maturity_wt=total(x) if maturity_month!=.  
drop x sum_balance

sort year code loandate
bysort year code: keep if _n==_N

***generate the change in maturity_wt (dmaturity_wt)
egen id=group(code)
xtset id year
gen dmaturity_wt=d.maturity_wt

keep if year==2005 | year==2006  //we need the info in the following year

***generate the change in credit rating (drating_b)
preserve
use samplex,clear
drop if  type_maturity>1 | (year(paydate)==year(loandate))  
drop if rating_b==.
sort year code loandate
bysort year code:keep if _n==_N
egen id=group(code)
xtset id year
gen drating_b=d.rating_b
gen drating_b3=1 if drating_b>0 & drating_b<.
replace drating_b3=0 if drating_b==0
replace drating_b3=-1 if drating_b<0
keep year code drating_b drating_b3
save x,replace
restore
merge 1:1 code year using x
drop if _merge==2
drop _merge

***generate the change in log of GDP per capita of the province
preserve
use gdp,clear
xtset province year
gen dlngdp=d.lngdp
keep province year dlngdp    
save x,replace
restore
merge m:1 province year using x
drop if _merge==2
drop _merge

***generate the change in financial variables
preserve
use financedata,clear
egen id=group(code)
xtset id year
gen lnasset=ln(asset*10000)
gen dlnasset=lnasset-l.lnasset
gen lev=liability/asset
gen dlev=lev-l.lev
gen roe=nincome/equity if equity>0
gen droe=roe-l.roe
gen asturn=sales/nfixas if nfixas>0
gen dasturn=asturn-l.asturn
gen cashas=casset/asset
gen dcashas=cashas-l.cashas
gen sgrow=sales/l.sales-1 if l.sales>0
replace sgrow=0 if sgrow==.
gen dsgrow=sgrow-l.sgrow
replace year=year+1   //we will use the lag of financial variables
keep code year dlnasset dlev droe dasturn dcashas dsgrow
save x,replace
restore
merge 1:1 code year using x
drop if _merge==2
drop _merge

keep if !missing(drating_b,dlnasset,dlev,droe,dasturn,dcashas,dsgrow,dmaturity_wt,dlngdp)

foreach var of varlist dasturn dsgrow {
winsor  `var', p(0.01) gen(`var'_w)
drop `var'
rename `var'_w `var'
}

xi:reg drating_b dlnasset dlev droe dasturn dcashas dsgrow dmaturity_wt dlngdp i.field i.year i.csrc_a,r
$out $table, $option2 $add2 
predict residual,r
save sample2_change,replace

xi:oprobit drating_b3 dlnasset dlev droe dasturn dcashas dsgrow dmaturity_wt dlngdp i.field i.year i.csrc_a,r
$out $table, $option2 $add1 


***************************************************
***Spline analysis and ROC analysis
***************************************************

*Spline analysis

use sample3,clear

mkspline  res 3 = residual, pctile

global table table4

xi: probit default  residual  lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000) ) 
$out $table, $option1 $add1 
xi: dprobit default residual  lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 

xi: probit default  res1 res2 res3  lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default res1 res2 res3  lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1

*ROC

foreach var of varlist residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp {
scalar a="`var'"
scalar b="residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp"
global c=subinword(scalar(b),scalar(a),"",.)

capture drop p1
capture drop p2
qui xi: probit default $c i.field i.year i.csrc_a
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
predict   p2  if e(sample) ,p
roccomp default p1 p2
}

foreach var of varlist res1 res2 res3 lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp {
scalar a="`var'"
scalar b="res1 res2 res3 lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp"
global c=subinword(scalar(b),scalar(a),"",.)

capture drop p1
capture drop p2
qui xi: probit default $c i.field i.year i.csrc_a
predict p1 if e(sample),p
qui xi: probit default res1 res2 res3 lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
predict p2 if e(sample),p
roccomp default p1 p2
}


***************************************************
***Bank Relationship Analysis (bootstrap, 500 times)
***************************************************

use sample3,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)  //the variable times indicates borrowing frequency
gen d1=(g1==2)  //a firm is classified as a frequent (infrequent) borrower if it has borrowed from the bank more than (less than or equal to) the sample median
egen g2=xtile(dif_month),nq(2)  //the variable dif_month indicates borrowing duration
gen d2=(g2==2)  //a firm is classified as having a long- (short-) term relationship with the bank if the duration is greater than (less than or equal to) the sample median
gen residualXd1=residual*d1
gen residualXd2=residual*d2

global table table5

/*frequent VS. infrequent*/

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2
$out $table, $option2 $add1 

/*long VS. short*/

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2
$out $table, $option2 $add1 

/*state VS. non-state*/

*match each state-owned firm with a non-state-owned firm based on industry and size: sampling without replacement

use sample3,clear  
local 1 code
local 2 year
local 3 state  
local 4 csrc_a 
local 5 asset
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5'  
gen order=_n
save x,replace
keep if `3'==1 
scalar maxnum=_N

use x,clear
drop if _n>0
save y,replace
save z,replace

local i=1
use x,clear   
while `i'<=scalar(maxnum)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  //non-SOE, the same year&industry
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear 
merge 1:1 code year using sample3
drop if _merge==2
drop _merge
gen residualXstate=residual*state
save sample3_match,replace

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) // the variable Dum cannot be estimated here 
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 



***************************************************
***logistic regression
***************************************************

use sample3,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)

global table table6

/*overall sample*/
xi: logistic default  rating_b  lnasset lev roe  asturn cashas sgrow dum lagdefault public state maturity_wt lngdp i.field i.year i.csrc_a,r
$out $table, $option1 $add1 eform

/*frequent VS. infrequent*/
xi: logistic default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 eform
xi: logistic default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 eform

/*long VS. short*/
xi: logistic default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 eform
xi: logistic default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 eform

/*state VS. non-state*/
use sample3_match,clear
xi: logistic  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 eform
xi: logistic  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) 
$out $table, $option2 $add1 eform


***************************************************
***ROC analysis
***************************************************

use sample3,clear

capture drop g1 g2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)

capture drop p1
capture drop p2
global cond g1==1
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2
capture drop p1
capture drop p2
global cond g1==2
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2

capture drop p1
capture drop p2
global cond g2==1
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2
capture drop p1
capture drop p2
global cond g2==2
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2

use sample3_match,clear

capture drop p1
capture drop p2
global cond state==0
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2
capture drop p1
capture drop p2
global cond state==1
qui xi: probit default lnasset lev roe asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond 
predict   p1  if e(sample),p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample),p
roccomp default p1 p2



************************************************************************************************************************************************************
***Internet Appendix: Robust test
************************************************************************************************************************************************************

/*implicit loan rollover analysis*/

use samplex,clear
keep if year==2005 | year==2006
keep code notecode loandate balance default  //notecode is loan ID
rename balance balance2 
rename notecode notecode2
rename loandate paydate   //be used to identify implicit loan rollover
rename default default2
sort code paydate notecode2 
save sample_0506,replace 

use sample_loan,clear
preserve
keep code year notecode paydate balance default
joinby code paydate using sample_0506 
keep if balance==balance2
drop if default==1         
gsort code year notecode - default2
bysort code year notecode: keep if _n==1  
gen rollover=1
keep code year notecode rollover default2  //notecode is loan ID
save x,replace
restore
merge 1:1 code year notecode using x  
drop if _merge==2
drop _merge
replace rollover=0 if rollover==.  //generate the variable rollover at the loan level

bysort year code: egen sum_balance=total(balance)
gen x=maturity_month*balance/sum_balance
bysort year code: egen maturity_wt=total(x) if maturity_month<.  
drop x 

bysort year code:egen sum_default=sum(default)  
replace sum_default=1 if sum_default>0 & sum_default<.
drop default
rename sum_default default

bysort year code:egen sum_rollover=sum(rollover)  //generate the variable rollover at the firm level
replace sum_rollover=1 if sum_rollover>0 & sum_rollover<.
drop rollover
rename sum_rollover rollover 

sort year code loandate 
bysort year code: keep if _n==_N

drop if rollover==1 & default==0  //drop the observations that are associated with implicit rollovers but no default on their loans

foreach var of varlist asturn sgrow  {
winsor  `var', p(0.01) gen(`var'_w)
drop `var'
rename `var'_w `var'
}


xi:reg  rating_b lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r
capture drop residual
predict residual, r  //get the proxy for bank specialty
save xxx,replace

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2
keep code year default residualXd1 residualXd2 residual times dif_month lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a g1 g2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2
$out $table, $option2 $add1 

use xxx,clear  //match each state-owned firm with a non-state-owned firm based on industry and size: without replacement
local 1 code
local 2 year
local 3 state  
local 4 csrc_a 
local 5 asset  
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5' 
gen order=_n
save x,replace
drop if _n>0
save y,replace
save z,replace
use x,clear
keep if `3'==1 
scalar a=_N
local i=1
use x,clear   
while `i'<=scalar(a)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear 
merge 1:1 code year using xxx
drop if _merge==2
drop _merge
gen residualXstate=residual*state
keep code year default residualXstate residual state lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 


/*Alternative definitions of default*/

use sample_loan,clear 

*excluding firms that partially default on their loans from our sample & re-define default as when all the short-term loans borrowed by the firm in a given year are written off or unpaid
bysort code year: egen mean_default=mean(default)
gen default_3=0 if mean_default==0 & default==0
replace default_3=1 if mean_default!=default
replace default_3=2 if mean_default==1 & default==1
drop if default_3==1  //excluding firms that partially default on their loans from our sample
capture drop default   //re-define default when the firm defaults on all the short-term loans
gen default=1 if default_3==2
replace default=0 if default_3==0 | default_3==1 

/*
capture drop default
gen default=(condition==3)  //unpaid loan
*/

bysort year code: egen sum_balance=total(balance)  
gen x=maturity_month*balance/sum_balance
bysort year code: egen maturity_wt=total(x) if maturity_month<.  
drop x 

bysort year code:egen sum_default=total(default)  
replace sum_default=1 if sum_default>0 & sum_default<.
replace sum_default=0 if sum_default==0
capture drop default
rename sum_default default

sort year code loandate 
bysort year code: keep if _n==_N

foreach var of varlist asturn sgrow  {
winsor  `var', p(0.01) gen(`var'_w)
drop `var'
rename `var'_w `var'
}


xi:reg  rating_b lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r
capture drop residual
predict residual, r  //get the proxy for bank specialty
save xxx,replace

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1  
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2
$out $table, $option2 $add1 

use xxx,clear  //match each state-owned firm with a non-state-owned firm based on industry and size: without replacement
local 1 code
local 2 year
local 3 state  
local 4 csrc_a 
local 5 asset  
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5'  
gen order=_n
save x,replace
drop if _n>0
save y,replace
save z,replace
use x,clear
keep if `3'==1 
scalar a=_N
local i=1
use x,clear  
while `i'<=scalar(a)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear  
merge 1:1 code year using xxx
drop if _merge==2
drop _merge
gen residualXstate=residual*state

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) 
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 


/*Bank Specialty based on difference-in-difference analysis*/

use sample3,clear
drop residual
merge 1:1 code year using sample2_change
drop if _merge==2
drop _merge
drop if residual==.
save xxx,replace

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow  lagdefault  maturity_wt lngdp  ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp  if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp  if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp  if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp  if g1==2
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe asturn cashas sgrow  lagdefault  maturity_wt lngdp  ,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp  if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp  if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp  if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow  lagdefault  maturity_wt lngdp  if g2==2
$out $table, $option2 $add1 


/*Alternative measures for the depth of banking relationship*/

use sample3,clear
capture drop g1 
capture drop d1 
egen g1=xtile(times),nq(3)
gen d1=(g1==3)
gen residualXd1=residual*d1
drop if g1==2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==3,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==3
$out $table, $option2 $add1 

use sample3,clear
capture drop  g2
capture drop  d2
egen g2=xtile(dif_month),nq(3)
gen d2=(g2==3)
gen residualXd2=residual*d2
drop if g2==2

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==3,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==3
$out $table, $option2 $add1 


use sample3,clear
capture drop times
preserve  //produce the frequency in the previous year
use sample0,clear
keep if year==2003
bysort code :gen times1=_N
bysort code :keep if _n==1
replace year=2004
keep code year times1
save x1,replace
use sample0,clear
keep if year==2004
bysort code :gen times2=_N
bysort code :keep if _n==1
replace year=2005
keep code year times2
save x2,replace
restore
merge 1:1 code year using x1
drop if _merge==2
drop _merge
merge 1:1 code year using x2
drop if _merge==2
drop _merge
replace times1=0 if times1==. & year==2004
replace times2=0 if times2==. & year==2005
gen times=times1 if year==2004
replace times=times2 if year==2005

capture drop g1
capture drop d1 
egen g1_1=xtile(times1),nq(2)
egen g1_2=xtile(times2),nq(2)
gen d1=1 if g1_1==2 | g1_2==2
replace d1=0 if d1==.
gen residualXd1=residual*d1

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if d1==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if d1==0
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if d1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if d1==1
$out $table, $option2 $add1 



/*Alternative variable constructions for firm-specific hard information*/


*labor/gdpgrow

use sample3,clear
preserve
use gdp,clear
keep province year gdpgrow
save x,replace
restore
merge m:1 province year using x
drop if _merge==2
drop _merge
replace lnasset=ln(labor)  //use the number of employees per firm as a proxy for size
replace lngdp=gdpgrow  //replace provincial log(GDP) with regional GDP growth to capture macro-economic uncertainty
drop if lnasset==. | gdpgrow==.

xi:reg  rating_b lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r
capture drop residual
predict residual, r  //get the proxy for bank specialty
save xxx,replace

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2
keep code year default residualXd1 residualXd2 residual times dif_month lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a g1 g2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2
$out $table, $option2 $add1 

use xxx,clear  //matching
local 1 code
local 2 year
local 3 state  
local 4 csrc_a 
local 5 lnasset
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5' 
gen order=_n
save x,replace
drop if _n>0
save y,replace
save z,replace
use x,clear
keep if `3'==1 
scalar a=_N
local i=1
use x,clear   
while `i'<=scalar(a)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear  
merge 1:1 code year using xxx
drop if _merge==2
drop _merge
gen residualXstate=residual*state
keep code year default residualXstate residual state lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) 
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 


*using contemporaneous financial variables

use sample3,clear
drop lnasset lev roe asturn sgrow dum cashas asset sales equity nincome nfixas 
preserve
use financedata,clear 
egen id=group(code)
tsset id year
gen lnasset=ln(asset*10000)
gen lev=liability/asset
gen roe=nincome/equity if equity>0
gen sgrow=sales/l.sales-1 if l.sales>0
gen cashas=casset/asset
gen asturn=sales/nfixas if nfixas>0
keep code year lnasset lev roe asturn sgrow cashas asset sales equity nincome nfixas
save x,replace
restore
merge 1:1 code year using x
drop if _merge==2
drop _merge
gen dum=(sgrow==.)
replace sgrow=0 if sgrow==.

drop if missing(rating_b, lnasset, lev, roe, asturn, cashas, sgrow, dum, lagdefault, public, state, maturity_wt, lngdp)

foreach var of varlist asturn sgrow  roe {
winsor  `var', p(0.01) gen(`var'_w)
drop `var'
rename `var'_w `var'
}

xi:reg  rating_b lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r
capture drop residual
predict residual, r  //get the proxy for bank specialty
save xxx,replace

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2
keep code year default residualXd1 residualXd2 residual times dif_month lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a g1 g2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2
$out $table, $option2 $add1 

use xxx,clear  //matching
local 1 code
local 2 year
local 3 state  
local 4 csrc_a 
local 5 asset  
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5' 
gen order=_n
save x,replace
drop if _n>0
save y,replace
save z,replace
use x,clear
keep if `3'==1 
scalar a=_N
local i=1
use x,clear   
while `i'<=scalar(a)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear
merge 1:1 code year using xxx
drop if _merge==2
drop _merge
gen residualXstate=residual*state
keep code year default residualXstate residual state lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) 
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 


/*Loan-level analysis*/

use sample_loan,clear

foreach var of varlist asturn sgrow  {
winsor  `var', p(0.01) gen(`var'_w)
drop `var'
rename `var'_w `var'
}

xi:reg  rating_b lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_month lngdp i.field i.year i.csrc_a,cluster(code)
predict residual, r  //get the proxy for bank specialty
save xxx,replace

use xxx,clear
capture drop m1 
capture drop m2
capture drop d1 
capture drop d2
preserve  //use the same standard of sustained banking replationship as the sample in main regressions
use sample3,clear
qui sum times,d
scalar m1=r(p50)
qui sum dif_month,d
scalar m2=r(p50)
restore
gen d1=(times>scalar(m1))
gen d2=(dif_month>scalar(m2))
gen residualXd1=residual*d1
gen residualXd2=residual*d2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if d1==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if d1==0
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if d1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if d1==1
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if d2==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if d2==0
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if d2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if d2==1
$out $table, $option2 $add1 


use sample3,clear  //matching
local 1 code
local 2 year
local 3 state   
local 4 csrc_a 
local 5 asset   
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5'   
gen order=_n
save x,replace
drop if _n>0
save y,replace
save z,replace
use x,clear
keep if `3'==1 
scalar a=_N
local i=1
use x,clear   
while `i'<=scalar(a)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear  
keep code year
merge 1:m code year using xxx
drop if _merge==2
drop _merge
gen residualXstate=residual*state

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_month lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_month lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) 
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_month lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 


/*Large firm sub-sample*/

use sample3,clear
egen big=xtile(lnasset),nq(3)
drop if big==1
save xxx,replace

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2
$out $table, $option2 $add1 

use xxx,clear  //matching
local 1 code
local 2 year
local 3 state  
local 4 csrc_a 
local 5 asset  
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5' 
gen order=_n
save x,replace
drop if _n>0
save y,replace
save z,replace
use x,clear
keep if `3'==1 
scalar a=_N
local i=1
use x,clear  
while `i'<=scalar(a)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear  
merge 1:1 code year using xxx
drop if _merge==2
drop _merge
gen residualXstate=residual*state
keep code year default residualXstate residual state lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) 
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 


/*add the squared terms when estimating bank specialty*/

use sample3,clear

foreach var of varlist asturn sgrow {
winsor  `var', p(0.01) gen(`var'_w)
drop `var'
rename `var'_w `var'
}
foreach var of varlist lnasset lev roe asturn cashas sgrow maturity_wt lngdp {
gen square_`var'=`var'^2
}

xi:reg  rating_b  square_*  lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r
capture drop residual
predict residual, r  //get the proxy for bank specialty
save xxx,replace

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2
$out $table, $option2 $add1 

use xxx,clear  //matching
local 1 code
local 2 year
local 3 state  
local 4 csrc_a 
local 5 asset  
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5'  
gen order=_n
save x,replace
drop if _n>0
save y,replace
save z,replace
use x,clear
keep if `3'==1 
scalar a=_N
local i=1
use x,clear   
while `i'<=scalar(a)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear
merge 1:1 code year using xxx
drop if _merge==2
drop _merge
gen residualXstate=residual*state
keep code year default residualXstate residual state lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) 
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 


/*split the continuous variables when estimating bank specialty*/


use sample3,clear

foreach var of varlist asturn sgrow {
winsor  `var', p(0.01) gen(`var'_w)
drop `var'
rename `var'_w `var'
}
foreach var of varlist lnasset lev roe asturn cashas sgrow maturity_wt lngdp {
mkspline spline_`var'  3 = `var', pctile      // 3 splines
*mkspline spline_`var' 4 = `var', pctile      // 4 splines
*mkspline spline_`var' 5 = `var', pctile      // 5 splines
}


xi:reg  rating_b spline_*  dum lagdefault public state  i.field  i.year i.csrc_a,r
capture drop residual
predict residual, r  //get the proxy for bank specialty
save xxx,replace

*relationship analysis

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2
keep code year default residualXd1 residualXd2 residual times dif_month lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a g1 g2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g1==2
$out $table, $option2 $add1 

xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if g2==2
$out $table, $option2 $add1 

use xxx,clear  //matching
local 1 code
local 2 year
local 3 state  
local 4 csrc_a 
local 5 asset  
keep `1' `2' `3' `4'  `5' 
gsort - `3' `2' `4'  `5'  
gen order=_n
save x,replace
drop if _n>0
save y,replace
save z,replace
use x,clear
keep if `3'==1 
scalar a=_N
local i=1
use x,clear   
while `i'<=scalar(a)  {
tempvar b
gen `b'=abs(`5'-`5'[1])
keep if  `3'==0 & `2'==`2'[1] & `4'==`4'[1]  
gsort  `b'  
keep if _n==1  
scalar m=order[1]   
if scalar(m)<. {         
use x,clear
keep if order==`i' | order==scalar(m)
append using y
save y,replace
}
else  { 
use x,clear            
keep if order==`i'
append using z
save z,replace
}
use x,clear
drop if order==`i' | order==scalar(m)
save x,replace
local i=`i'+1
}
use y,clear
save match,replace

use match,clear
merge 1:1 code year using xxx
drop if _merge==2
drop _merge
gen residualXstate=residual*state
keep code year default residualXstate residual state lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp field year csrc_a

xi: probit  default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residualXstate residual state lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0,vce(boot,reps(500) seed(2000))
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==0
$out $table, $option2 $add1 
xi: probit  default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1,vce(boot,reps(500) seed(2000)) 
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if state==1
$out $table, $option2 $add1 

*ROC analysis

use xxx,clear

capture drop g1 g2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)

capture drop p1
capture drop p2
global cond g1==1
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2
capture drop p1
capture drop p2
global cond g1==2
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2

capture drop p1
capture drop p2
global cond g2==1
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2
capture drop p1
capture drop p2
global cond g2==2
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2

use match,clear
merge 1:1 code year using xxx
drop if _merge==2
drop _merge

capture drop p1
capture drop p2
global cond state==0
qui xi: probit default lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2
capture drop p1
capture drop p2
global cond state==1
qui xi: probit default lnasset lev roe asturn cashas sgrow    lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p1  if e(sample) ,p
qui xi: probit default residual lnasset lev roe asturn cashas sgrow    lagdefault public maturity_wt lngdp i.field i.year i.csrc_a if $cond
predict   p2  if e(sample) ,p
roccomp default p1 p2


/*Controlling for province fixed effects instead of region fixed effects*/

use sample3,clear

xi:reg  rating_b lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt  i.province i.year i.csrc_a,r
capture drop residual
predict residual, r  //get the proxy for bank specialty
save xxx,replace

use xxx,clear
capture drop g1 g2
capture drop d1 d2
egen g1=xtile(times),nq(2)
egen g2=xtile(dif_month),nq(2)
gen d1=(g1==2)
gen d2=(g2==2)
gen residualXd1=residual*d1
gen residualXd2=residual*d2

global table tablex

xi: probit default residualXd1 residual times lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a ,cluster(code)
$out $table, $option1 $add1 
xi: dprobit default residualXd1 residual times lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a 
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a if g1==1,cluster(code)
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a if g1==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a if g1==2,cluster(code)
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a if g1==2
$out $table, $option2 $add1 


xi: probit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a,cluster(code)
$out $table, $option2 $add1 
xi: dprobit default residualXd2 residual dif_month lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a if g2==1,cluster(code)
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a if g2==1
$out $table, $option2 $add1 
xi: probit default  residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a if g2==2,cluster(code)
$out $table, $option2 $add1 
xi: dprobit default residual  lnasset lev roe  asturn cashas sgrow dum lagdefault public maturity_wt  i.province i.year i.csrc_a if g2==2
$out $table, $option2 $add1 



***OLS for Tables 2&4: The standardized coefficient


use sample3,clear

global table tablex

xi: reg  default lnasset lev roe asturn cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r beta
$out $table, $option1   
$out $table, $option2 stats(beta)   
xi: reg  default rating_b i.field i.year i.csrc_a,r beta
$out $table, $option2   
$out $table, $option2 stats(beta)   
xi: reg  default rating_b lnasset lev roe asturn  cashas sgrow dum lagdefault public state  maturity_wt lngdp i.field i.year i.csrc_a,r beta
$out $table, $option2   
$out $table, $option2 stats(beta)   

global table tablex

mkspline  res 3 = residual, pctile

xi: reg default  residual  lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option2   
$out $table, $option2 stats(beta) 
xi: reg default  res1-res3  lnasset lev roe asturn cashas sgrow dum lagdefault public maturity_wt lngdp i.field i.year i.csrc_a ,vce(boot,reps(500) seed(2000))
$out $table, $option2   
$out $table, $option2 stats(beta) 



******************************************************************
***Discriptive Statistics
******************************************************************

/*Descriptive Statistics for Sample Firms: Table 1*/

use sample3,clear
replace asset=asset/10000  //here total assets are reported in 100 millions; originally they are in 10 thousands
replace sales=sales/10000  //here sales are reported in 100 millions; originally they are in 10 thousands
replace sum_balance=sum_balance/100000000  //here loan balance is reported in 100 millions
replace labor=. if labor==0  //labor is the number of employees 
*keep if year==2004
*keep if year==2005
save xxx,replace

tabstat rating_b asset sales sum_balance labor lev roe asturn cashas sgrow state,s(mean sd n) c(s) f(%10.3f)   
bysort default: tabstat rating_b asset sales sum_balance labor lev roe asturn cashas sgrow state,s(mean sd n) c(s) f(%10.3f)   

clear all
input str20 vname 
"rating_b"  
"asset" 
"sales"
"sum_balance" 
"labor" 
"lev" 
"roe" 
"asturn" 
"cashas"
"sgrow"
"state"
end
gen tv=.
gen sig=.
gen dif=.
save x,replace

use xxx,clear
foreach var of varlist rating_b asset sales sum_balance labor lev roe asturn cashas sgrow state {
ttest `var',une by(default)
scalar a=r(t)
scalar b=r(p)
use x,clear
replace tv=scalar(a) if vname=="`var'"
replace sig=scalar(b) if vname=="`var'"
replace dif=r(mu_1)-r(mu_2) if vname=="`var'"
save x,replace
use xxx,clear
}
use x,clear



/*Loan Characteristics: Appendix Table A5*/

use samplex,clear
egen id=group(code)
drop if type_maturity==.  //drop one loan with missing information on maturity
save xxx,replace

use xxx,clear
bysort year type_maturity:egen num_firm=nvals(id)  //compute the number of distinct observations
bysort year type_maturity:egen num_loan=count(id)
gen x=balance/1000000000  //reported in bilion
bysort year type_maturity:egen sum_principal=sum(x)
bysort year type_maturity:egen mean_principal=mean(x)
gen mean_principal2=mean_principal*1000  //reported in million 
bysort year type_maturity:keep if _n==_N
keep year type_maturity num_firm num_loan sum_principal mean_principal2


/*Internal Credit Rating and Default Characteristics: Appendix Table A6*/

use samplex,clear
drop if type_maturity==.  //drop one loan with missing information on maturity
save xxx,replace

use xxx,clear  //at the loan level
bysort year type_maturity:egen num_rating=count(rating_b)
bysort year type_maturity:egen mean_rating=mean(rating_b)
bysort year type_maturity:egen num_defaut=count(default)
bysort year type_maturity:egen mean_default=mean(default)
bysort year type_maturity:keep if _n==_N
keep year type_maturity num_rating mean_rating num_defaut mean_default


use xxx,clear  //at the firm level
preserve 
use samplex,clear
drop if default==.
bysort year type_maturity code:egen sum_default=total(default)
replace sum_default=1 if sum_default>0 & sum_default<.
capture drop default
rename sum_default default
bysort year type_maturity code: keep if _n==_N
keep year type_maturity code default
save x,replace
restore
capture drop default
sort year type_maturity code loandate
bysort year type_maturity code:keep if _n==_N
merge 1:1 year type_maturity code using x
drop if _merge==2
drop _merge
bysort year type_maturity:egen num_rating=count(rating_b)
bysort year type_maturity:egen mean_rating=mean(rating_b)
bysort year type_maturity:egen num_defaut=count(default)
bysort year type_maturity:egen mean_default=mean(default)
bysort year type_maturity:keep if _n==_N
keep year type_maturity num_rating mean_rating num_defaut mean_default



